function [Feature, FeatureName] = BeatClassGroup( SNRf, xCWT, MovMedianSig, DistMat, Tree, Win)

    global QRS, global Sig
   
    DistMat = squareform( DistMat );
    DistMatLog = abs( DistMat );
    DistMatLog = DistMatLog + 1;
    DistMatLog = log( DistMatLog );
    
    
    %Signal tranforms
    ecgOrig = Sig.data;
    ecgTKEO = Sig.data;
    ecgTKEO = [ ecgTKEO(1); ecgTKEO; ecgTKEO(end) ];
    ecgTKEO = ecgTKEO(2:end-1).^2 - ecgTKEO(1:end-2).*ecgTKEO(3:end);
    ecgLOG = log( abs( ecgOrig( :, 1 ) ) + 1 );
    xCWTdiff = diff( real( [xCWT(1,2); xCWT(:,2); xCWT(end,2)] ) );
    
    %Signal Power   
    ecgFilt = ecgOrig - MovMedianSig(5,:)' - MovMedianSig(6,:)';
    ecgFilt = abs( ecgFilt );
    ecgFilt( ecgFilt >= prctile( ecgFilt, 95 ) ) = prctile( ecgFilt, 95 );
    PWR = rms( ecgFilt )*sqrt(median( QRS.RR(:) )); clear ecgFilt
        
    %Transform weights
    TW.MovMedianRICA = [-0.4488; -0.4102; -0.4833; -0.6299];
    TW.GroupMemberPCA = [0.573131577543580 ;0.570163435787455; 0.588586315823149];
    TW.GroupMember = [0.5752, 0.6107, 0.6485];

    
    
    %Shlukovani do skupin pro rzn prahy
    CutOff = [0.07 0.10 0.13];
    CutOffLen = length( CutOff );
    GroupIndex = zeros( CutOffLen, QRS.Count );

    for ii = 1:CutOffLen
        GroupIndex( ii, : ) = cluster( Tree, 'Cutoff', CutOff( ii ), 'criterion', 'distance' ) ;
    end
    GroupIndex = GroupIndex';
    
    
    %Nastaven dlky okna
    Win = ( Win*Sig.fs )/1000;
    Win = ceil( Win );
    Win = -Win:+Win;
    
    
    QRSGroupIndex = GroupIndex( :, 2 );
    QRSGroupMax = max( QRSGroupIndex );
    
    %% Parametrizace QRS pro jednotliv morfologick skupiny
    for i = 1:QRS.Count
         Ctrl = 1;
        Range = QRS.R(i) + Win;
        
        %% SNRf param
        %1
        Feature( i, Ctrl ) = min( SNRf( Range ) );
        FeatureName{ Ctrl } = 'SNRf';
        Ctrl = Ctrl + 1;
      
        
        %% Signal effective power
        %2
        Aux = PWR;
        Feature( i, Ctrl ) = FeatureNormalize( Aux, 1140, -700, 3800, 'true' );
        FeatureName{ Ctrl } = 'PWRglobal';
        Ctrl = Ctrl + 1;
       
        
        %% MovMedian
        %3
        Aux = zeros( 1, 4 );
        for ii = 1:4
            Aux(ii) = max( abs( MovMedianSig( ii, Range ) ) );
        end
        Aux = log( Aux );
        Aux = Aux*TW.MovMedianRICA;
        Feature( i, Ctrl ) = FeatureNormalize( Aux, -4.6, -7, 4, 'false' );
        FeatureName{ Ctrl } = 'MovMed';
        Ctrl = Ctrl + 1;
        
            %% Cluster analysis
        Aux2 = ones( 1, CutOffLen );
        for ii = 1:CutOffLen
            Aux = GroupIndex( i, ii );
            Aux = sum( GroupIndex( i, : ) == Aux );
            switch Aux
                case 3
                    Aux2( ii ) = 0.8;
                case 2
                    Aux2( ii ) = 1;
                case 1
                    Aux2( ii ) = 1.2;
            end
        end
        Aux2 = Aux2.*TW.GroupMember;
        Aux2 = Aux2*TW.GroupMemberPCA;
        Aux2 = 0.5*( Aux2^2 );
        if Aux2 > 1, Aux2 = 1; end
        
        %34
        Aux = Aux2;
        Feature( i, Ctrl ) = FeatureNormalize( Aux, 0.634, -0.3, 0.3, 'false' );
        FeatureName{ Ctrl } = 'QRSTreeCut';
        Ctrl = Ctrl + 1;
        
     
        
        %% Corr coeff stat
        %35
        Aux = median( DistMat(i , : ) );
        Feature( i, Ctrl ) = FeatureNormalize( Aux, 0.017, -0.02, 0.55, 'true' );
        FeatureName{ Ctrl } = 'QRSCorrMed';
        Ctrl = Ctrl + 1;
        
        %36
        Aux = skewness( DistMat(i , : ) );
        Feature( i, Ctrl ) = FeatureNormalize( Aux, 1.4, -7, 7, 'false' );
        FeatureName{ Ctrl } = 'QRSCorrSKW';
        Ctrl = Ctrl + 1;
        
        %37
        Aux = moment( DistMat(i , : ), 5 );
        Feature( i, Ctrl ) = FeatureNormalize( Aux, 5e-5, -4e-3, 4e-3, 'false' );
        FeatureName{ Ctrl } = 'QRSCorrMOM5';
        Ctrl = Ctrl + 1;
        
        %38
        Aux = moment( DistMat(i , : ), 7 );
        Feature( i, Ctrl ) = FeatureNormalize( Aux, 2.6e-10, -0.5e-3, 1.5e-3, 'false' );
        FeatureName{ Ctrl } = 'QRSCorrMOM7';
        Ctrl = Ctrl + 1;
        
        %% QRS CWT envelope FWHM
    
        Envelope = abs( xCWT( :, 5 ) );
        Envelope = sgolayfilt( Envelope, 2, 51 );

        [Pks, Locs] = findpeaks( -Envelope, 'MinPeakDistance', 20);
        Drift = spline( Locs, Pks, 1:Sig.length );
        Envelope = Envelope + Drift(:);

        Win2 = 140;
        Win2 = ( Win2*Sig.fs )/1000;
        Win2 = ceil( Win2 );
        Win2 = -Win2:+Win2;
        Thresh = [0.5, 0.25];
        FWHM = zeros( 1, 2 );

        Range2 = QRS.R(i) + Win2;
        for kk = 1:2

            CtrlEnv = 0;
            ecgSeq = Envelope( Range2 );
            [Pks, Locs] = findpeaks( ecgSeq );
            if isempty( Pks ) 
                continue
            end
            [~, Pos] = max( Pks );
            Pks = Pks( Pos );
            Locs = Locs( Pos );

            ind = Locs;
            while ecgSeq( ind - 1 ) >= Thresh( kk )*Pks
                ind = ind - 1;
                if ind <= 1
                    CtrlEnv = 1;
                    break
                end
            end

            ind2 = Locs;
            while ecgSeq( ind2 + 1 ) >= Thresh( kk )*Pks
                ind2 = ind2 + 1;
                if ind2 >= length( Range2 )
                    CtrlEnv = 1;
                    break
                end
            end

            if CtrlEnv == 1
                FWHM( kk ) = 0;
            else
                FWHM( kk ) = ind2 - ind;

                if FWHM( kk ) >= 70
                    FWHM( kk ) = 70;
                end
                FWHM( kk ) = FWHM( kk )/70;
            end
        end
        %39
        Aux = FWHM(1);
        Feature( i, Ctrl ) = FeatureNormalize( Aux, 0.4, -0.4, 0.4, 'false' );
        FeatureName{ Ctrl } = 'FWHM1';
        Ctrl = Ctrl + 1;

        %40
        Aux = FWHM(2);
        Feature( i, Ctrl ) = FeatureNormalize( Aux, 0.53, -0.3, 0.5, 'false' );
        FeatureName{ Ctrl } = 'FWHM2';
        Ctrl = Ctrl + 1;
        
    end
    
    for i = 1 : QRSGroupMax
        
        Ctrl = 11;
        QRSIndexes = find( QRSGroupIndex == i );
        QRSGroupCount = length( QRSIndexes ); %Poet QRS ve skupine
        
        Win3 = -20:100;
        WinLen = length( Win3 );
        
        Aux1 = zeros( WinLen , QRSGroupCount ); %Pomocna promenna
        Aux2 = zeros( WinLen , QRSGroupCount ); %Pomocna promenna
        Aux3 = zeros( WinLen , QRSGroupCount ); %Pomocna promenna
%         Aux4 = zeros( WinLen , QRSGroupCount ); %Pomocna promenna
%         Aux5 = zeros( WinLen , QRSGroupCount ); %Pomocna promenna
%         Aux6 = zeros( WinLen , QRSGroupCount ); %Pomocna promenna
%         Aux7 = zeros( WinLen , QRSGroupCount ); %Pomocna promenna
%         Aux8 = zeros( WinLen , QRSGroupCount ); %Pomocna promenna
%         Aux9 = zeros( WinLen , QRSGroupCount ); %Pomocna promenna
%         Aux10 = zeros( WinLen , QRSGroupCount ); %Pomocna promenna
%         
        
        %Segmentace DWT signlu s QRS komplexy podle zaazen do skupiny kk
        for ii = 1:QRSGroupCount
            RWaveLoc = QRS.Onset( QRSIndexes( ii ) );
            if isnan( RWaveLoc )
                continue
            end
            Range = RWaveLoc + Win3;
            Aux1( :, ii ) = ecgOrig( Range );
            Aux2( :, ii ) = ecgTKEO( Range );
            Aux3( :, ii ) = ecgLOG( Range );
%             Aux4( :, ii) =  Envelope( Range );
%             Aux5( :, ii) =  xCWT( Range, 1 );
%             Aux6( :, ii) =  xCWT( Range, 2 );
%             Aux7( :, ii) =  xCWT( Range, 3 );
%             Aux8( :, ii) =  xCWT( Range, 4 );
%             Aux9( :, ii) =  xCWT( Range, 5 );
%             Aux10( :, ii) = xCWTdiff( Range );
        end
        
        medOrig = median( Aux1, 2 );   
        medTKEO = median( Aux2, 2 );   
        medLOG = median( Aux3, 2 );   
%         medENV = median( Aux4, 2 );   
%         medCWT1 = median( real( Aux5 ), 2 );
%         medCWT2 = median( real( Aux6 ), 2 );
%         medCWT3 = median( real( Aux7 ), 2 );
%         medCWT4 = median( real( Aux8 ), 2 );
%         medCWT5 = median( real( Aux9 ), 2 );
%         medCWTdiff = median( Aux10, 2 );
        
        clear -regexp ^Aux\d{1}$
 
        
        %% xDWT rms decrease rate
        if isnan( QRS.Onset( QRSIndexes ) )
            continue
        end
        
        Onset = QRS.R( QRSIndexes ) - QRS.Onset( QRSIndexes );
        Onset = ceil( median( Onset ) );
        Offset = QRS.Offset( QRSIndexes ) - QRS.Onset( QRSIndexes );
        Offset = floor( median( Offset ) );
        
        Range1 = 19: 19 + 25;
        Range1( Range1 < 1) = [];
        Range2 = 19 + 29:19 + 60;
        Range2( Range2 > WinLen) = [];
        Range3 = 19 : 19 + 60;
        Range3( Range3 > WinLen) = [];
      

        Aux = rms( medOrig( Range1, 1 ) ); %pridane
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 300, -300, 1800, 'true' );
        FeatureName{ Ctrl } = 'ecgRMS_R1';
        Ctrl = Ctrl + 1;
        
        Aux = rms( medOrig( Range2, 1 ) ); %pridane
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 100, -100, 1100,  'true' );
        FeatureName{ Ctrl } = 'ecgRMS_R2';
        Ctrl = Ctrl + 1;
        
        Aux = rms( medOrig( Range3, 1 ) ); %pridane
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 230, -230, 1200, 'true' );
        FeatureName{ Ctrl } = 'ecgRMS_R3';
        Ctrl = Ctrl + 1;
        
        Aux = skewness( medOrig( Range1, 1 ) );%100 /***
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, -2, 2, 'false' );
        FeatureName{ Ctrl } = 'ecgSKW_R1';
        Ctrl = Ctrl + 1;
        
        Aux = skewness( medOrig( Range2, 1 ) );%101 */****
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, -4, 4, 'false' );
        FeatureName{ Ctrl } = 'ecgSKW_R2';
        Ctrl = Ctrl + 1;
        
        Aux = skewness( medOrig( Range3, 1 ) );%102 /**
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, -3, 3, 'false' );
        FeatureName{ Ctrl } = 'ecgSKW_R3';
        Ctrl = Ctrl + 1;
        
        Aux = kurtosis( medOrig( Range1, 1 ) );%103 */***
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 2, -1, 3, 'true' );
        FeatureName{ Ctrl } = 'ecgKURT_R1';
        Ctrl = Ctrl + 1;
        
        Aux = kurtosis( medOrig( Range2, 1 ) );%104  /**
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 2, -1, 10,  'true' );
        FeatureName{ Ctrl } = 'ecgKURT_R2';
        Ctrl = Ctrl + 1;
        
        Aux = kurtosis( medOrig( Range3, 1 ) );%105 */***
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 5, -4, 4, 'false' );
        FeatureName{ Ctrl } = 'ecgKURT_R3';
        Ctrl = Ctrl + 1;
        
        Aux = moment( medOrig( Range1, 1 ), 5 );%106 /*
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 121e10, -2.4e14, 4e14, 'false' );
        FeatureName{ Ctrl } = 'ecgMOM5_R1';
        Ctrl = Ctrl + 1;
        
        Aux = moment( medOrig( Range2, 1 ), 5 );%107 /**
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 2.6e8, -2.7e13, 3.4e13, 'false' );
        FeatureName{ Ctrl } = 'ecgMOM5_R2';
        Ctrl = Ctrl + 1;
        
        Aux = moment( medOrig( Range3, 1 ), 5 );%108 /*
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 126e10, -3.3e14, 6.1e14, 'false' );
        FeatureName{ Ctrl } = 'ecgMOM_R3';
        Ctrl = Ctrl + 1;        
        
        Aux = moment( medOrig( Range1, 1 ), 6 );%109 /**
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 22e14, -2.18e15, 3e18, 'true' );
        FeatureName{ Ctrl } = 'ecgMOM6_R1';
        Ctrl = Ctrl + 1;
        
        Aux = moment( medOrig( Range2, 1 ), 6 );%110 /***
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 7.14e11, -7.14e11, 3.23e17, 'true' );
        FeatureName{ Ctrl } = 'ecgMOM6_R2';
        Ctrl = Ctrl + 1;
        
        Aux = moment( medOrig( Range3, 1 ), 6 );%110 /***
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 2.27e15, -2.27e15, 7.26e18, 'true' );
        FeatureName{ Ctrl } = 'ecgMOM6_R3';
        Ctrl = Ctrl + 1;
        
        Aux = rms( medTKEO( Range1, 1 ) ); %pridane
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 1.8e4, -1.8e4, 1.57e5, 'true' );
        FeatureName{ Ctrl } = 'tkeoRMS_R1';
        Ctrl = Ctrl + 1;
        
        Aux = rms( medTKEO( Range2, 1 ) );%113 */***
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 196, -186, 2.2e4, 'true' );
        FeatureName{ Ctrl } = 'tkeoRMS_R2';
        Ctrl = Ctrl + 1;    
        
        %21
        Aux = skewness( medTKEO( Range1, 1 ) ); %pridane
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 1.32, -2.5, 2.5, 'false' );
        FeatureName{ Ctrl } = 'tkeoSKW_R1';
        Ctrl = Ctrl + 1;
        
        Aux = skewness( medTKEO( Range2, 1 ) ); %pridane
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 1.35, -9, 7, 'false' );
        FeatureName{ Ctrl } = 'tkeoSKW_R2';
        Ctrl = Ctrl + 1;
        
        Aux = kurtosis( medTKEO( Range1, 1 ) ); %pridane
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 3.55, -2.5, 10, 'false' );
        FeatureName{ Ctrl } = 'tkeoKURT_R1';
        Ctrl = Ctrl + 1;
        
        Aux = kurtosis( medTKEO( Range2, 1 ) ); %pridane
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 9, -8, 50,  'false' );
        FeatureName{ Ctrl } = 'tkeoKURT_R2';
        Ctrl = Ctrl + 1;
        
        Aux = moment( medTKEO( Range1, 1 ), 5 ); %pridane
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 4.68e21, -4.68e21, 3e26, 'true' );
        FeatureName{ Ctrl } = 'tkeoMOM5_R1';
        Ctrl = Ctrl + 1;
        
        Aux = moment( medTKEO( Range2, 1 ), 5 ); %pridane
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 5.3e11, -3.25e17, 1e21, 'true' );
        FeatureName{ Ctrl } = 'tkeoMOM5_R2';
        Ctrl = Ctrl + 1;
        
        Aux = rms( medLOG ( Range1, 1 ) );%121 */***
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 4.9, -2.5, 2.5, 'false' );
        FeatureName{ Ctrl } = 'ecgLogRMS_R1';
        Ctrl = Ctrl + 1;
        
        Aux = rms( medLOG ( Range2, 1 ) );%122 /**
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 4.16, -3, 3, 'false' );
        FeatureName{ Ctrl } = 'ecgLogRMS_R2';
        Ctrl = Ctrl + 1;
        
        Aux = rms( medLOG ( Range3, 1 ) );%123 */***
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 4.44, -2.5, 3, 'false' );
        FeatureName{ Ctrl } = 'ecgLogRMS_R3';
        Ctrl = Ctrl + 1;
        
        Aux = kurtosis( medLOG ( Range1, 1 ) );%124 */***
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 2.5, -1.3, 15, 'false' );
        FeatureName{ Ctrl } = 'ecgLogKURT_R1';
        Ctrl = Ctrl + 1;
        
        Aux = kurtosis( medLOG ( Range2, 1 ) );%125  /** pripadne vyradit
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 3.8, -3, 20, 'false' );
        FeatureName{ Ctrl } = 'ecgLogKURT_R2';
        Ctrl = Ctrl + 1;
        
        Aux = kurtosis( medLOG ( Range3, 1 ) );%126  /**
        Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 3.26, -2.5, 18, 'false' );
        FeatureName{ Ctrl } = 'ecgLogKURT_R3';
        Ctrl = Ctrl + 1;
        
%         Aux = rms( medCWT1( Range2 ) );%2
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 1.8, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = rms( medCWT2( Range2 ) );%11    /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 18, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = rms( medCWT3( Range2 ) );%21    /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 300, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = rms( medCWT4( Range2 ) );%29    /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 500, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = rms( medCWT5( Range2 ) );%37 /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 750, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = rms( medCWTdiff( Range2 ) );%47    /*
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 40, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWT1( Range3 ), 5 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 6.6, -1e4, 1e4, 'false' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWT2( Range3 ), 5 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 8.15e9, -1e13, 1e13, 'false' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWT3( Range3 ), 5 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 7.72e11, -5e14, 5e14, 'false' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWT4( Range3 ), 5 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 5.3e12, -3e15, 3e15, 'false' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWT5( Range3 ), 5 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 1.25e13, -1e16, 1e16, 'false' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWTdiff( Range3 ), 5 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, -2e8, -1e11, 1e11, 'false' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWT1( Range3 ), 6 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 1.5e5, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWT2( Range3 ), 6 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 4e15, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWT3( Range3 ), 6 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 4e17, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWT4( Range3 ), 6 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 3e18, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWT5( Range3 ), 6 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 2e19, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWTdiff( Range3 ), 6 ); %4  /**
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 4e13, 'true' );
%         Ctrl = Ctrl + 1;
        
%         Aux = moment( medCWTdiff( Range1 ), 6 );%52 */***
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 7e13, 'true' );
%         Ctrl = Ctrl + 1;
%         
%         Aux = moment( medCWTdiff( Range2 ), 6 );%52 */***
%         Feature( QRSIndexes , Ctrl ) = FeatureNormalize( Aux, 0, 0, 2e8, 'true' );
%         Ctrl = Ctrl + 1;
%         
        
        
        %% QRS Off - On Amplitude
        
        Locs1 = 21 - 7 : 21 - 2;
        Locs2 = (21 + Offset ) + 2:(21 + Offset ) + 10;
        Locs2( Locs2 > WinLen ) = [];
        if isempty( Locs2 )
            Locs2 = WinLen;
        end
        Aux = median( medOrig( Locs2 ) ) -  median( medOrig( Locs1 ) );
        Aux = Aux/rms( medOrig( 21:(21 + Offset) ));
        
        Feature( QRSIndexes, Ctrl )= FeatureNormalize( Aux, -0.07, -4.5, 4, 'false' );
        FeatureName{ Ctrl } = 'QRSLimDiffAmp';
        Ctrl = Ctrl + 1;
        
        Aux = std( medOrig( Locs2 ) ) -  std( medOrig( Locs1 ) );
        Feature( QRSIndexes, Ctrl )= FeatureNormalize( Aux, 0, 0, 1e3, 'false' );
        FeatureName{ Ctrl } = 'QRSLimSTDAmp';
        Ctrl = Ctrl + 1;
        

        
    end
end