function [ Tree, DistMat ] = QRS_corr
    
    global QRS
    global Options
    
      
    QRS.GroupIndex = ones( QRS.Count, 1 ); %Preallocation of QRS group indexes;
    
    % QRS segmentation
    [ Data_cluster ] = ECG_segment( QRS.R, QRS.GroupIndex, Options.Window );
    
    % Morphology clustering
    [ Tree, DistMat, DistMat2, Lag_mat ] = Morph_clustering( Data_cluster );
%     QRS.MorphGroupCount = max( QRS.GroupIndex );
   
    % QRS ref. optimization
     QRS_Optimization( Lag_mat );  
     
     % SVD noise classification
%      [ Data_cluster ] = ECG_segment( Sig, R_optim, Group.max_group_index(:,1), Options.Window );
%      [Param1, Param2] = SVD_class( Data_cluster );

        
end

%% Segmentace QRS komplex podle detekovanch pozic QRS v rozsahu ref.  okno.     
 function [ Data_cluster ] = ECG_segment( Ref, GroupIndex, Win )
%
    global Sig
    global QRS
    
    Win = ( Win*Sig.fs )/1000;
    Win = ceil( Win );
    Win = -Win:+Win;
    WinLen = length( Win );
    GroupCount = max( GroupIndex );
    
    Data_cluster = cell( GroupCount, 1 );
    Counter = ones( 1, GroupCount );
    
    for i = 1:QRS.Count
        Data_cluster{ GroupIndex(i), 1 }( 1:WinLen, Counter( GroupIndex(i) )) = Sig.data( Ref(i) + Win );
        Counter( GroupIndex(i) ) = Counter( GroupIndex(i) ) + 1;
    end

 end



%% Morphology clustering
function [ Tree, DistMat, DistMat2, LagMat ] = Morph_clustering( Data_cluster )
    
    global QRS
    global Options
    global Group
    global Sig
    
    if Options.Standard == true
        Data_cluster{:} = zscore( Data_cluster{:} );
    else
        Data_cluster{:} = detrend( Data_cluster{:} );
    end
    
    DistMat = zeros( 1, QRS.Count*( QRS.Count-1 )/2 );
    DistMat2 = zeros( 1, QRS.Count*( QRS.Count-1 )/2 );
    LagMat = zeros( QRS.Count, QRS.Count );
%     rrInt_mat = zeros( QRScount, QRScount );
    
    Ind = 1;
    for i = 1:QRS.Count
        for k = i+1:QRS.Count
            [rr, lag] = xcorr( Data_cluster{:}( :,i ) , Data_cluster{:}( :,k ) , 'coeff');
            [rr_max, rr_pos] = max( rr );
            rr_lag = lag( rr_pos );

            DistMat( Ind ) = 1 - abs( rr_max );
            LagMat( i,k ) = rr_lag;

            Ind = Ind + 1;
        end
    end
    
%     DistMat = DistMat + DistMat';
    LagMat = LagMat + LagMat';

    Tree = linkage( DistMat, 'weighted' );
    
    Cut_off = 0.1;  
    
    QRS.GroupIndex = cluster( Tree, 'Cutoff', Cut_off, 'criterion', 'distance' ) ;
    QRS.GroupIndex = QRS.GroupIndex(:);     
    QRS.GroupCount = max( QRS.GroupIndex ); 
        
    
%     Group( Options.Index ) = {B};
    
%     Cut_off = 0.05:0.01:0.34;
%     
%     for k = 1:length( Cut_off )
%         QRS.GroupIndex = cluster( Tree, 'Cutoff', Cut_off( k ), 'criterion', 'distance' ) ;
%         QRS.GroupIndex = QRS.GroupIndex(:);
%         
%         Group.Count(k, Sig.Index) = max( QRS.GroupIndex ); 
%         Aux = mode( QRS.GroupIndex );
%         
%         Group.BiggestRelative(k, Sig.Index) = sum( QRS.GroupIndex == Aux )./length(QRS.GroupIndex);
%         
%         Ind1 = 0;
%         Ind2 = 0;
%         for m = 1:max( QRS.GroupIndex )
%             S = sum( QRS.GroupIndex == m );
%             if S < 3
%                 Ind1 = Ind1 + 1;
%                 Ind2 = Ind2 + S;
%             end
%         end
%         Group.LessThan3GCount(k, Sig.Index) = Ind1;
%         Group.LessThan3RCount(k, Sig.Index) = Ind2/length( QRS.GroupIndex  );
%     end
    %     rrInt_mat = 0.25.*(1 + tansig( (rrInt_mat - 20)./15 ) );   
end


%% QRS position optimization
function QRS_Optimization( LagMat )
    
    global QRS

    min_poz = []; ind = [];
    
    for i = 1:QRS.GroupCount
        ind = find( QRS.GroupIndex == i );
        if length( ind  ) > 2
            Lag_n = LagMat( ind , ind );
            [~, min_poz] = min( sum( Lag_n.^2 , 2 ).^0.5 );
            Lag_n = [-1*Lag_n( min_poz, 1:min_poz-1 ) Lag_n(  min_poz, min_poz:end )];
            QRS.R( ind, 1 ) = QRS.R( ind, 1 ) - Lag_n(:);
        end
    end
end

%% Largest group SVD variability

function [Param1, Param2] = SVD_class( Data_cluster )
    
    cellz_DC1 = cellfun(@size , Data_cluster, 'uni', false);
    cellz_DC1 = [ cellz_DC1{:} ]; cellz_DC1 = cellz_DC1( 2:2:end )';
    [~ , DC1_max_ind] = max( cellz_DC1 );
% 
    [~,S,~] = svd( zscore( Data_cluster{ DC1_max_ind , 1 } )');
     S = diag(S); S = S.^2; S = S./sum(S);

    tdata = 0:1:length(S)-1;
    tdata = tdata(:);
    ydata = S;

    fun = @(x)sum( (ydata - exp(-x(1).*tdata)).^2 ); %Optimalizovan funkce
    x = 0.5; %Poten odhad parametr
    bestx = fminsearch(fun,x);
    ymodel = exp(-bestx.*tdata);
    
    Param1 = log(bestx);
    Param2 = 1 - (sqrt( sum( (ydata - ymodel).^2 ))/sqrt( sum( (ydata - mean(ydata)).^2 )));
end




