function [QRS, QRS1_sum] = QRSdet_TKEO_2(fs_ECG,ECG,typ)
%------ NAPOVEDA ----------------------------------------------------------

% vstupni parametry
% fs_ECG : pouzita vzorkovaci frekvence v Hz
% ECG : vstupni signal ve formatu *.mat, radkovy vektor
% typ : 1, 2 nebo 3 (1 = ICRC, 2 = MIT, 0 = ICRC-MIT)

% vystupni parametry
% QRS : pozice QRS komplexu v zadanem svodu

%------ NASTAVENI PARAMETRU -----------------------------------------------

% parametry programu
% param(1) - fd
% param(2) - fh
% param(3) - nsobek prahu

if typ == 1
   param = [7 12 0.68];     % 98.5784%
elseif typ == 2         
   param = [12 19 0.39];    % 99.0464%
%    param = [14 40 0.39];    % 99.0464%
else
   param = [10 17 0.5];     % 98.5529%
end

hpp = fir1(251,[param(1) param(2)]/(fs_ECG/2));
ekg_f = filtfilt(hpp,1,ECG);
TKEO = ekg_f(2:end-1).^2 - ekg_f(1:end-2).*ekg_f(3:end);

N = 2*fs_ECG; % 1.9*fs_ECG
prah = param(3)*movingstd(TKEO,N/2,'central'); %'central''backward'
% *******************************
nadprah = find(TKEO>prah); % indexy nadprah. hodnot, napr. [5 6 7 15 16 17]
nad1 = [0 nadprah(1:end-1)]; %                    napr. [0 5 6  7 15 16]
dif = nadprah - nad1; %                           napr. [5 1 1  8  1  1]
zacatky = find(dif>1); %                          napr. [1 4] 
konce = [zacatky(2:end)-1 length(nadprah)]; %     napr. [3 6]

QRS1 = []; maxTKEO = [];
for i = 1:length(zacatky)
   [hodnota, pol] = max(TKEO(nadprah(zacatky(i)):nadprah(konce(i))));
   poloha = nadprah(zacatky(i)) + pol;
   maxTKEO = [maxTKEO hodnota];
   QRS1 = [QRS1 poloha];
end

QRS1_sum = QRS1;
% korekce ********************
RR5 = sum(diff(QRS1(1:6)));
prumRR = RR5/5;
k = 7;
while k < length(QRS1),
    if QRS1(k)-QRS1(k-1) < round(200*fs_ECG/1000); % refrakterita
        QRS1 = [QRS1(1:k-1) QRS1(k+1:end)];
        maxTKEO = [maxTKEO(1:k-1) maxTKEO(k+1:end)];
    elseif QRS1(k+1)-QRS1(k-1) < 1.15*prumRR
        QRS1 = [QRS1(1:k-1) QRS1(k+1:end)];
        maxTKEO = [maxTKEO(1:k-1) maxTKEO(k+1:end)];
    else
        if 0.85*prumRR < QRS1(k)-QRS1(k-1) && 1.15*prumRR > QRS1(k)-QRS1(k-1)
            RR5 = sum(diff(QRS1(k-5:k)));
            prumRR = RR5/5;
        end
        k = k+1;
    end
end
% konec korekci **************

% figure(1) % kresby *******************
% subplot(211)
% plot(ECG(1:end-1))
% subplot(212)
% plot(TKEO), hold on
% plot(prah,'red')
% for i = 1:length(QRS1),
%     plot(QRS1(i),maxTKEO(i),'o'),
% end
% % for i = 1:length(QRSref),
% %     plot(QRSref(i),0,'*'),
% % end
% hold off
QRS = QRS1;
end
% Se=SP/(SP+FN)=P(T+|QRS), PP=SP/(SP+FP)=P(QRS|T+)
% prah=std, refr=150 a 200 ms: A=97.5267, Se=96.7578, PP=98.2956
% 6-13 Hz,prah=0,5*std, refr=200ms A=97.8705, Se=98.0373, PP=97.7036,
% 1...100: A=99.9780
% 2...101: A=99.8928 
% 3...102: 6-13 Hz: A=93.7143 ***
% 3...102: 13-20 Hz: A=99.9771 ***
% 13-20 Hz,prah=0,5*std,refr=200ms A=98.5742, Se=98.5935, PP=98.5548,  

% korekce ******************** vsechno: 98.5316 98.9835 98.7576
% 1: 1: Se=100, PP=100; uspesnost=100
% 2: 98.9349 99.1461 99.0405
% 3: 99.3001 99.6336 99.4668
% 4: 95.8917 97.1332 96.5124
function s = movingstd(x,k,windowmode)
% movingstd: efficient windowed standard deviation of a time series
% usage: s = movingstd(x,k,windowmode)
%
% Movingstd uses filter to compute the standard deviation, using
% the trick of std = sqrt((sum(x.^2) - n*xbar.^2)/(n-1)).
% Beware that this formula can suffer from numerical problems for
% data which is large in magnitude. Your data is automatically
% centered and scaled to alleviate these problems.
%
% At the ends of the series, when filter would generate spurious
% results otherwise, the standard deviations are corrected by
% the use of shorter window lengths.
%
% arguments: (input)
%  x   - vector containing time series data
%
%  k   - size of the moving window to use (see windowmode)
%        All windowmodes adjust the window width near the ends of
%        the series as necessary.
%
%        k must be an integer, at least 1 for a 'central' window,
%        and at least 2 for 'forward' or 'backward'
%
%  windowmode - (OPTIONAL) flag, denotes the type of moving window used
%        DEFAULT: 'central'
%
%        windowmode = 'central' --> use a sliding window centered on
%            each point in the series. The window will have total width
%            of 2*k+1 points, thus k points on each side.
%        
%        windowmode = 'backward' --> use a sliding window that uses the
%            current point and looks back over a total of k points.
%        
%        windowmode = 'forward' --> use a sliding window that uses the
%            current point and looks forward over a total of k points.
%
%        Any simple contraction of the above options is valid, even
%        as short as a single character 'c', 'b', or 'f'. Case is
%        ignored.
%
% arguments: (output)
%  s   - vector containing the windowed standard deviation.
%        length(s) == length(x)

% check for a windowmode
if (nargin<3) || isempty(windowmode)
  % supply the default:
  windowmode = 'central';
elseif ~ischar(windowmode)
  error 'If supplied, windowmode must be a character flag.'
end
% check for a valid shortening.
valid = {'central' 'forward' 'backward'};
ind = find(strncmpi(windowmode,valid,length(windowmode)));
if isempty(ind)
  error 'Windowmode must be a character flag, matching the allowed modes: ''c'', ''b'', or ''f''.'
else
  windowmode = valid{ind};
end

% length of the time series
n = length(x);

% check for valid k
if (nargin<2) || isempty(k) || (rem(k,1)~=0)
  error 'k was not provided or not an integer.'
end
switch windowmode
  case 'central'
    if k<1
      error 'k must be at least 1 for windowmode = ''central''.'
    end
    if n<(2*k+1)
      error 'k is too large for this short of a series and this windowmode.'
    end
  otherwise
    if k<2
      error 'k must be at least 2 for windowmode = ''forward'' or ''backward''.'
    end
    if (n<k)
      error 'k is too large for this short of a series.'
    end
end

% Improve the numerical analysis by subtracting off the series mean
% this has no effect on the standard deviation.
x = x - mean(x);
% scale the data to have unit variance too. will put that
% scale factor back into the result at the end
xstd = std(x);
x = x./xstd;

% we will need the squared elements 
x2 = x.^2;

% split into the three windowmode cases for simplicity
A = 1;
switch windowmode
  case 'central'
    B = ones(1,2*k+1);
    s = sqrt((filter(B,A,x2) - (filter(B,A,x).^2)*(1/(2*k+1)))/(2*k));
    s(k:(n-k)) = s((2*k):end);
  case 'forward'
    B = ones(1,k);
    s = sqrt((filter(B,A,x2) - (filter(B,A,x).^2)*(1/k))/(k-1));
    s(1:(n-k+1)) = s(k:end);
  case 'backward'
    B = ones(1,k);
    s = sqrt((filter(B,A,x2) - (filter(B,A,x).^2)*(1/k))/(k-1));
end

% special case the ends as appropriate
switch windowmode
  case 'central'
    % repairs are needed at both ends
    for i = 1:k
      s(i) = std(x(1:(k+i)));
      s(n-k+i) = std(x((n-2*k+i):n));
    end
  case 'forward'
    % the last k elements must be repaired
    for i = (k-1):-1:1
      s(n-i+1) = std(x((n-i+1):n));
    end
  case 'backward'
    % the first k elements must be repaired
    for i = 1:(k-1)
      s(i) = std(x(1:i));
    end
end

% catch any complex std elements due to numerical precision issues.
% anything that came out with a non-zero imaginary part is
% indistinguishable from zero, so make it so.
s(imag(s) ~= 0) = 0;

% restore the scale factor that was used before to normalize the data
s = s.*xstd;
end