function GroupMed = T_end_estim_v3( xCWT )

    global QRS
    global Sig

    
    %Informace o indexech skupin QRS komplex
    GroupInd = QRS.GroupIndex;
    maxGroupInd = QRS.GroupCount;
    
    %Inicializace vektor parametr
    QRS.Onset = nan( QRS.Count, 1 ); %Prealokace matice pro hranice QRS
    QRS.Offset = nan( QRS.Count, 1 ); %Prealokace matice pro hranice QRS


    %% Parametrizace QRS pro jednotliv morfologick skupiny
    for i = 1 : maxGroupInd
        
        
        GroupIndLog = (GroupInd == i ); %Logick indexace QRS nleicch do skupiny kk
        
        %Vpoet velikosti okna z medinov vzdlenosti z RR-1 a RR+1 pro skupinu kk
        AuxB.RRMed = QRS.RR( GroupIndLog, : );
        AuxB.RRMed = floor( median( AuxB.RRMed(:) ) ); 
        if AuxB.RRMed > 200
            AuxB.RRMed = 200;
        end
        Range = -AuxB.RRMed:AuxB.RRMed; %Rozsah vzork pro vbr QRS s mean = 0;
        WinSize = length( Range );

        %Inicializace pomocnch promnnch
        QRSGroupRef = QRS.R( GroupIndLog ); %Skupinov pozice QRS
        CWTenv = zeros( WinSize, 1 ); %Oblka medinu skupinovch DWT koef.
%         SIGmedQRS = zeros( WinSize, 1 ); % Kumulovan QRS v originlnm zznamu
        
        %% Medinov reprezentace DWT koef. s orig sing.
        
        GroupMed = GroupQRSCumul( xCWT, QRSGroupRef, Range, WinSize );
           
        %Oblka 
        GroupMed = abs( GroupMed );
        CWTenv = sgolayfilt( GroupMed, 2, 31 );
        
%         [ SIGmedQRS, ~ ] = GroupQRSCumul( Sig.data, QRSGroupRef, Range, WinSize );
        
        
        %% Rozmen QRS v psmu 2
        [ Onset, Offset, PeakPos ] = QRSDelin( CWTenv, WinSize );
        QRS.Onset( GroupIndLog, 1 ) = Range(1) + QRSGroupRef + Onset;
        QRS.Offset( GroupIndLog, 1 ) = Range(1) + QRSGroupRef + Offset;
 
        

    end

    % Logicka indexace detekovanych komplexu s rozmerenymi hranicemi
    validQRS = and( ~isnan( QRS.Onset(:,1) ), ~isnan( QRS.Offset(:,1) ) );
    QRS.Offset( not( validQRS )) = NaN;
    QRS.Onset( not( validQRS )) = NaN;
    
    
end        

%% Kumulace v oblasti CWT
function [ CWTmedQRS ] = GroupQRSCumul( xCWT, QRSGroupRef, Range, WinSize )
        global Setting

        QRSGroupCount = length( QRSGroupRef ); %Poet QRS ve skupine
        Aux = zeros( WinSize , QRSGroupCount ); %Pomocna promenna
    
        %Segmentace DWT signlu s QRS komplexy podle zaazen do skupiny kk
        for i = 1:QRSGroupCount
            Aux( :, i ) = xCWT( Range + QRSGroupRef( i ) );
        end
        
        CWTmedQRS = median( Aux, 2 );   
end



%% Rozmereni QRS komplex
function [ Onset, Offset, PeakPos ] = QRSDelin( CWTenv, WinSize )
       

       %Detekce pozice maxima v psmu 2
        CWTenv = CWTenv.^2;
        [ pks, locs] = findpeaks( CWTenv( floor( WinSize./4 ): floor( WinSize.*(3/4) ) ), 'MinPeakDistance', 20 );
        if isempty( locs )
            Onset = NaN; Offset = NaN; PeakPos = NaN;
            return
        end
        PeakPos = locs( pks == max( pks ) ) + floor( WinSize./4 );

        %Normalizace dat
        
        CWTenv = CWTenv./CWTenv( PeakPos );

        %Pozice QRS onset
        Onset = PeakPos - 3;
        while 1
            if CWTenv( Onset ) <= CWTenv( Onset - 2 ) %Kontrola "sestupn tendence"
                break
            elseif CWTenv( Onset  ) <= 0.1 %Kontrola prahovn
                break
            elseif abs( PeakPos - Onset ) >= WinSize/4 %Kontrola maximln vzdlenosti hranice od vrcholu (limit = 1/4 okna)
                break
            else
                Onset = Onset - 1;
            end
        end

        %Pozice QRS offset
        Offset = PeakPos + 3;
        while 1
            if CWTenv( Offset ) <= CWTenv( Offset + 2 ) %Kontrola "sestupn tendence"
                break
            elseif CWTenv( Offset ) <= 0.1 %Kontrola prahovn
                break
            elseif abs( PeakPos - Offset ) >= WinSize/4 %Kontrola maximln vzdlenosti hranice od vrcholu (limit = 1/4 okna)
                break
            else
                Offset = Offset + 1;
            end
        end

end
    

