function [QRS] = detQRS_ST_02( fs, x, ~ )

% == Parameters ===========================================================
% Feature
fmez = [5 20];          % [Hz] spectrogram
% Standard phase
trhM = 0.375;          	% [%] threshold is XX% of mean of found last A peaks
A = 4;                	% [-] how many last peaks used for determining of threshold 
% Multiple detection
REF = 0.29;           	% [s] refractory period
% Search-back detection
RRmed = 9;           	% [-] how manny RR in flowing median
RR_M = 1.0;            	% [-] how many times could be actual RR longer than median RR 
lambda = 0.02;        	% [-] slope of the exponencial function
thrMIN = 0.09;         	% [%] minimal threshold is XX% of mean of found last B peaks
B = 3;                	% [-] how many last peaks used for determining of minimal threshold
% Other rules
RR_MM = 10;           	% [-] how many times is possible to be actual RR longer than median RR
learning_time = 2*fs; 	% [s] learning time

% Simulated annealing
% fmez = [6 24]; trhM = 0.35; A = 4; REF = 0.29; RRmed = 7; RR_M = 1.1; lambda = 0.025; thrMIN = 0.1; B = 4;
% =========================================================================
% -- Feature --------------------------------------------------------------
f_od = fmez(1);          % Hz
f_do = fmez(2);          % Hz
% step_t = 1;              % vz
step_f = 1;              % Hz

% load timer
% cas = tic;
[fea_ST] = feature_ST( x, fs, f_od, f_do, step_f );
% cas = toc(cas);
% time = [time cas];
% save('timer', 'time');


% -- Decision rulez -------------------------------------------------------
N = length(x);
REF = floor(REF*fs);

% QRS = decision_rule_02(fea_ST, fs, REF, trhM, pmax, N);
% QRS = decision_rule_01_st(fea_ST, trhM, REF, RRmed, RR_M, thrMIN, lambda, RR_MM, learning_time, N);

QRS = decision_rule_02_st(fea_ST, trhM, REF, RRmed, RR_M, thrMIN, lambda, RR_MM, learning_time, N, A, B);

% plot(fea_ST); hold on; plot(QRS,fea_ST(QRS),'or');

% Supress warning
% [msg id] = lastwarn;
% warning('off',id)
end

function [fea_ST] = feature_ST( x, fs, f_od, f_do, step_f )
 
% -- Pre-Calculation ------------------------------------------------------

    N = length(x);
    t = 0:1/fs:(N-1)/fs;
    f = round((f_od : step_f : f_do)*(N/fs));
    F = length(f);
    
    gauss = cell(1,F);
    for i = 1 : F
        gauss{i} = g_window(N,f(i));
    end
% -----

    [ST] = S_tr_Fr_Pre(x, N, t, f, F, gauss);
%     [ST,~,~] = S_tr(x,fs,f_od,f_do,step_t,step_f);
 
    ESS = abs(ST).^2;
  	fea_ST = abs( sum( ESS .* log10(ESS) ) );

end

function [ST] = S_tr_Fr_Pre(x, N, t, f, F, gauss)

    if size(x,1) < size(x,2); x = x'; end

    % -- S-transform ----------------------------------------------------------
    
    vector_fft = fft(x);
    vector_fft = [vector_fft,vector_fft];

    ST = zeros(length(f),length(t));
    if f(1) == 0
        ST(1,:) = mean(x);
    else
        ST(1,:) = ifft(vector_fft(f(1)+1:f(1)+N) .* gauss{1});
    end

    for i = 2 : F
        ST(i,:) = ifft(vector_fft(f(i)+1:f(i)+N) .* gauss{i});
    end
    % -------------------------------------------------------------------------
end

function gauss = g_window(length,freq)

% Function to compute the Gaussion window for
% function Stransform. g_window is used by function
% Stransform. Programmed by Eric Tittley
%
%-----Inputs Needed--------------------------
%
%length-the length of the Gaussian window
%
%freq-the frequency at which to evaluate
%  the window.
%factor- the window-width factor
%
%-----Outputs Returned--------------------------
%
%gauss-The Gaussian window
%
factor = 1;

vector(1,:) = 0:length-1;
vector(2,:) = -length:-1;
vector = vector.^2;   
vector = vector*(-factor*2*pi^2/freq^2);
% Compute the Gaussion window
gauss = sum(exp(vector));
end

function QRS = decision_rule_02_st(fea_ST, trhM, REF, RRmed, RR_M, thrMIN, lambda, RR_MM, learning_time, N, A, B)

feature = NaN(1,floor(N));
thr = feature;
QRS = []; y = [];

LF = 0;overTRH = 0; 
i = 0; thrDini = 0;
while i < N
    
    i = i + 1;
    feature(i) = fea_ST(i);
    
    if i > learning_time && LF == 0
        LF = 1;
    end

    if LF == 1  % learning period
        
        y = []; pom = feature(1:i); z = 1; k = 0;
        while isempty(y)
            [M, I] = max(pom);
            if I ~= z && I ~= i - k
            	thrLF = trhM * M;
                [y, QRS] = findpeaks(pom,'MinPeakHeight',thrLF,'MinPeakDistance',REF);

                if numel(y) < 2
                    LF = 0; learning_time = learning_time * 2; break
                else
                 	thr(1:i) = thrLF;
                    thr(i+1) = trhM * y(end);
                    MIN = thrMIN * y(end);
                    MAX = thr(i+1); 
                    RR_med  = median(diff(QRS));
                    last = QRS(end); 
                    LF = 2;
                end
            else
                if I == z
                    pom(z) = 0;
                    z = z+1;
                else
                    k = k+1;
                    pom(i - k + 1) = 0;
                end
            end
        end

    elseif LF == 2  % usual period
        
        thr(i+1) = thr(i);
        if feature(i) < thr(i)
            if overTRH == 1
                overTRH = 0; 
                [M, I] = max(feature(i_up : i));
                if I ~= 1
                    y(end+1) = M; 
                    QRS(end+1) = i_up + I - 1;
                    if (QRS(end) - last) < REF   % R-R les than REF
                        if y(end) > y(end-1)
                            y(end-1) = []; 
                            QRS(end-1) = [];
                        else
                            y(end) = []; 
                            QRS(end) = [];
                        end
                    end
                    y_pom = min([RRmed length(QRS)-1]);              	% V?po?et medi?nu RR z posledn?ch y_pom hodnot
                    RR_med = median(diff(QRS(end-y_pom:end)));      	% V?po?et medi?nu RR z posledn?ch y_pom hodnot
                    last = QRS(end);
    %                 thr(i+1) = trhM * y(end);
                    y_pom = min([A length(QRS)])-1;
                    thr(i+1) = trhM * mean(y(end-y_pom:end));
                    thrDini = 0;
                end
            else
                if (i - last) > REF
                    if (i - last) > RR_M*RR_med       % R-R more than 1.66*RR_med
                        if (i - last) > RR_MM*RR_med  % R-R more than 8.0*RR_med
%                             T = 0.99*max(feature(last+REF+1 : i)); 
%                             i = last+REF; 
%                             thr(i+1) = T; 
%                             thrDini = 0;
                            i = last + floor(RR_M*RR_med);
                            thrDini = 1;
                            MIN = MIN*0.5;
                        else
                            if thrDini == 0
                                MAX = thr(i); 
                                y_pom = min([B length(QRS)])-1;
                                MIN = min([thrMIN*mean(y(end-y_pom:end)) MAX]); 
%                                 MIN = min([thrMIN * y(end) MAX]); 
                            end
                            thrDini = thrDini + 1;
                            thr(i+1) = MIN + (MAX-MIN)*exp(-lambda*thrDini);  
                            searchBack = feature(last+REF+1 : i);

                            searchBack(searchBack<thr(i)) = 0;

                            if sum(searchBack) ~= 0
                                [M, I] = max(searchBack);
                                if I ~= 1
                                    y(end+1) = M; 
                                    QRS(end+1) = last+REF+1 + I - 1;
                                    y_pom = min([RRmed length(QRS)-1]);             	% V?po?et medi?nu RR z posledn?ch y_pom hodnot
                                    RR_med = median(diff(QRS(end-y_pom:end)));       	% V?po?et medi?nu RR z posledn?ch y_pom hodnot
                                    last = QRS(end); 
                                    y_pom = min([A length(QRS)])-1;
                                    thr(i+1) = trhM * mean(y(end-y_pom:end));
    %                                 thr(i+1) = trhM * y(end);
                                    thrDini = 0;
                                end
                            end
                        end              
                    end
                end
            end
        else    %feature(i) > thr(i)
            if overTRH == 0
                overTRH = 1;
                i_up = i;
            elseif (i - i_up) > 0.5*RR_med%RR_M*RR_med
                [M, I] = max(feature(i_up:i));
                if I ~= 1
                    y(end+1) = M; 
                    QRS(end+1) = i_up + I-1;
                    if (QRS(end) - last) < REF   % R-R les than REF
                        if y(end) > y(end-1)
                            y(end-1) = []; 
                            QRS(end-1) = [];
                        else
                            y(end) = []; 
                            QRS(end) = [];
                        end
                    end
                    y_pom = min([RRmed length(QRS)-1]);            	% V?po?et medi?nu RR z posledn?ch y_pom hodnot
                    RR_med = median(diff(QRS(end-y_pom:end)));        % V?po?et medi?nu RR z posledn?ch y_pom hodnot
                    last = QRS(end);
                    y_pom = min([A length(QRS)])-1;
                    thr(i+1) = trhM * mean(y(end-y_pom:end));
%                     thr(i+1) = trhM * y(end);
                end
                i_up = i;
            end
        end
    end
end

if overTRH == 1
    [M, I] = max(feature(i_up:i));
	if I ~= 1 && I < i-i_up+1-4
        y(end+1) = M; 
        QRS(end+1) = i_up + I-1;
        if (QRS(end) - last) < REF   % R-R les than REF
            if y(end) > y(end-1)
            	y(end-1) = []; 
              	QRS(end-1) = [];
            else
             	y(end) = []; 
              	QRS(end) = [];
            end
        end
	end
end

% figure(3);plot(feature,'b');hold on;plot(thr,'r');plot(QRS,y,'ok');hold off; %xlim([i-1000 i]);
% figure;plot(feature,'b');hold on;plot(thr,'r');plot(QRS,y,'ok'); xlim([i-1000 i+200]);

end

function QRS = decision_rule_02(fea_ST, fs, REF, trhM, pmax, N)

fea_ST = fea_ST/max(fea_ST);

[y_QRS, QRS] = findpeaks(fea_ST,'MinPeakHeight',trhM,'MinPeakDistance',REF);
QRS(end+1) = N;
y_QRS(end+1) = fea_ST(end);

last = 1; RR = 0.75*fs; 
if QRS(1) - last > RR*1.5
    p = 0;
    qrs = [];
    trh_down = trhM;
  	while isempty(qrs) && p < pmax+2 
        p = p+1;
        trh_down = trh_down/4;
        [y_qrs,qrs] = findpeaks(fea_ST(last:min([QRS(1),last+5*RR])),'MinPeakHeight',trh_down,'NPeaks',1);
    end
    QRS = [qrs QRS];
    y_QRS = [y_qrs y_QRS];
end

last = QRS(1); i = 2;
while i ~= length(QRS)+1
    if QRS(i) - last > RR*1.5
        p = 0;
        qrs = [];
        trh_down = y_QRS(i-1);
        while isempty(qrs) && p < pmax  
            p = p+1;
            trh_down = trh_down/4;
            [y_qrs,qrs] = findpeaks(fea_ST(last+REF:min([QRS(i),last+5*RR])),'MinPeakHeight',trh_down,'NPeaks',3);
            if ~isempty(qrs)
                log = qrs>qrs(1)+REF;
                qrs(log) = []; y_qrs(log) = [];
                [~,I] = max(y_qrs);
                qrs = qrs(I); y_qrs = y_qrs(I);
            end
        end
        QRS = [QRS(1:i-1) qrs+last+REF-1 QRS(i:end)];
        y_QRS = [y_QRS(1:i-1) y_qrs y_QRS(i:end)];
    end
    last = QRS(i);
    RR = QRS(i) - QRS(i-1);
    RR(RR<REF) = REF;
    RR(RR>2*fs) = 2*fs;
    i = i+1;
end
QRS(end) = [];

end


