function [Param1, Param2,Group] = QRS_corr(Sig, QRS, Options)
        
    Group.QRS_optim = QRS.global;
    Group.count = 1;
    Group.tree = [];
    QRS_Group = ones( QRS.count, 1 ); %Preallocation of QRS group indexes
    
    
    if QRS.count < 2, return, end  

    % QRS segmentation
    [ Data_cluster ] = ECG_segment( Sig, QRS.global, QRS_Group, Options.Window );
    
    % Morphology clustering
    [ Group.tree, Group.group_index, Group.max_group_index, Lag_mat, Group.tree_cutoff ] = Morph_clustering( Data_cluster, QRS.count, QRS.global, Options );
    Group.count = max( Group.group_index );
    
    % QRS ref. optimization
    [ Group.QRS_optim ] = QRS_Optimization( Lag_mat, Group );
     Group.QRS_optim( Group.QRS_optim < 1 ) = 0;
     Group.QRS_optim( Group.QRS_optim > Sig.length ) = Sig.length; 
     
     % SVD noise classification
     [ Data_cluster ] = ECG_segment( Sig, Group.QRS_optim, Group.max_group_index(:,1), Options.Window );
     [Param1, Param2] = SVD_class( Data_cluster );

        
end



%% Morphology clustering
function [ tree, group_index, group_index_maxGroup, lag_mat, tree_cutoff ] = Morph_clustering( Data_cluster, QRScount, QRS_global, Options )
    
    if Options.Standard == true
        Data_cluster{:} = zscore( Data_cluster{:} );
    else
        Data_cluster{:} = detrend( Data_cluster{:} );
    end
    
    RR = diff( [1; QRS_global] );

    dist_mat = ones( QRScount, QRScount );
%     lag_mat = zeros( QRScount, QRScount );
%     coh_mat = zeros( QRScount, QRScount );
%     rrInt_mat = zeros( QRScount, QRScount );
    group_index_maxGroup = zeros( QRScount, 4);
    
    for i = 1:QRScount
        for k = i+1:QRScount
            [rr, lag] = xcorr( Data_cluster{:}( :,i ) , Data_cluster{:}( :,k ) , 'coeff');
            [rr_max, rr_pos] = max( rr );
            rr_lag = lag( rr_pos );
            
%             FT_coh = abs(fft( rr, 300));
%             rrInt_mat( i,k ) = abs( RR(i) - RR(k) );
            
            dist_mat( i,k ) = 1 - rr_max;
%             coh_mat( i,k ) = max(FT_coh( 1:40 ));
            lag_mat( i,k ) = rr_lag;
        end
    end
%     rrInt_mat = rrInt_mat./max( max( rrInt_mat ) );
%     coh_mat = coh_mat./max( max( coh_mat ) );
    
    dist_mat = dist_mat + dist_mat';
%     rrInt_mat = rrInt_mat + rrInt_mat';
%     coh_mat = coh_mat + coh_mat';
%     lag_mat = lag_mat + lag_mat';
%     
%     rrInt_mat = 0.25.*(1 + tansig( (rrInt_mat - 20)./15 ) );
%     coh_mat = 1 - 0.5*(1 + tansig( (coh_mat - 10)./2 ) );
%     coh_mat( 1:length( coh_mat )+1:numel( coh_mat ) ) = 0;

    
%     figure;
%     subplot(2,2,1)
%     hist(dist_mat(:))
%     subplot(2,2,2)
%     hist(rrInt_mat(:))
%     subplot(2,2,3)
%     hist(coh_mat(:))    
%     subplot(2,2,4)
%     plot(FT_coh)
    
%     dist_mat_2 = sqrt( dist_mat.^2 + rrInt_mat.^2 + coh_mat.^2 );
    
%     tree = linkage( coh_mat, Options.Method, Options.Distance );
%     group_index = cluster( tree, 'Cutoff', Options.Cut_off, 'criterion','distance' ) ;
%     group_index_maxGroup = cluster( tree, 'maxclust', 3 ) ;
    
    tree = linkage( dist_mat, Options.Method, Options.Distance );
    group_index = cluster( tree, 'Cutoff', Options.Cut_off, 'criterion','distance' ) ;
    
    group_index_maxGroup(:,1) = cluster( tree, 'maxclust', 3 );
    cutoff = sort(tree(:,3));
    tree_cutoff(1) = cutoff( size( tree,1 )+2-3 );
    
%     tree = linkage( rrInt_mat, Options.Method, Options.Distance );
%     group_index_maxGroup(:,2) = cluster( tree, 'maxclust', 3 );
%     cutoff = sort(tree(:,3));
%     tree_cutoff(2) = cutoff( size( tree,1 )+2-3 );
%     
%     tree = linkage( coh_mat, Options.Method, Options.Distance );
%     group_index_maxGroup(:,3) = cluster( tree, 'maxclust', 3 );
%     cutoff = sort(tree(:,3));
%     tree_cutoff(3) = cutoff( size( tree,1 )+2-3 );
%     
%     tree = linkage( dist_mat_2, Options.Method, Options.Distance );
%     group_index_maxGroup(:,4) = cluster( tree, 'maxclust', 3 );
%     cutoff = sort(tree(:,3));
%     tree_cutoff(4) = cutoff( size( tree,1 )+2-3 );
%     
end


%% QRS position optimization
function [QRS_optim] = QRS_Optimization( Lag_mat, Group )
    Group.Count = max( Group.group_index );
    QRS_optim = Group.QRS_optim; 
    min_poz = []; ind = [];
    
    for i = 1:Group.Count
        ind = find( Group.group_index == i );
        if length( ind  ) > 1
            Group.Lag_n = Lag_mat( ind , ind );
            [~, min_poz] = min( sum( Group.Lag_n.^2 , 2 ).^0.5 );
            Group.Lag_n = [-1*Group.Lag_n( min_poz, 1:min_poz-1 ) Group.Lag_n(  min_poz, min_poz:end )];
            QRS_optim( ind, 1 ) = Group.QRS_optim( ind, 1 ) - Group.Lag_n(:);
        end
    end
end

%% Largest group SVD variability

function [Param1, Param2] = SVD_class( Data_cluster )
    
    cellz_DC1 = cellfun(@size , Data_cluster, 'uni', false);
    cellz_DC1 = [ cellz_DC1{:} ]; cellz_DC1 = cellz_DC1( 2:2:end )';
    [~ , DC1_max_ind] = max( cellz_DC1 );
% 
    [~,S,~] = svd( zscore( Data_cluster{ DC1_max_ind , 1 } )');
     S = diag(S); S = S.^2; S = S./sum(S);

    tdata = 0:1:length(S)-1;
    tdata = tdata(:);
    ydata = S;

    fun = @(x)sum( (ydata - exp(-x(1).*tdata)).^2 ); %Optimalizovan funkce
    x = 0.5; %Poten odhad parametr
    bestx = fminsearch(fun,x);
    ymodel = exp(-bestx.*tdata);
    
    Param1 = log(bestx);
    Param2 = 1 - (sqrt( sum( (ydata - ymodel).^2 ))/sqrt( sum( (ydata - mean(ydata)).^2 )));
end




