function [classifyResult] = challenge(recordName)
% Sample entry for the 2017 PhysioNet/CinC Challenge.
%
% INPUTS:
% recordName: string specifying the record name to process
%
% OUTPUTS:
% classifyResult: integer value where
%                     N = normal rhythm
%                     A = AF
%                     O = other rhythm
%                     ~ = noisy recording (poor signal quality)
%
% To run your entry on the entire training set in a format that is
% compatible with PhysioNet's scoring enviroment, run the script
% generateValidationSet.m
%
% The challenge function requires that you have downloaded the challenge
% data 'training_set' in a subdirectory of the current directory.
%    http://physionet.org/physiobank/database/challenge/2017/
%
% This dataset is used by the generateValidationSet.m script to create
% the annotations on your training set that will be used to verify that
% your entry works properly in the PhysioNet testing environment.
%
%
% Version 1.0
%
%
% Written by: Chengyu Liu and Qiao Li January 20 2017
%             chengyu.liu@emory.edu  qiao.li@emory.edu
%
% Last modified by:
%
%

load('SVMlinear_FS01091_StandResubst.mat')
[~,ecg,fs,~]=rdmat(recordName);

oldSlozka=cd('Kuba');
[Feature]=VUT_QRS(ecg);
cd(oldSlozka);
oldSlozka=cd('Kuba2');
[FeaturesPQRSPCA,~,FeaturePQRS1]=VUT_QRS2(ecg);
% [FeaturePQRS2]=VUT_QRS3(ecg);
cd(oldSlozka);

win = round(0.09*fs); 
SNRf = SNR_STFT3_cor(fs, ecg', win);

quality = segment7(SNRf,fs,0.09*fs,ecg');
qualityMax=quality(quality(:,3)==min(quality(:,3)),1:2);%beru ten radek, kde se treti sloupec rovna maximu tretich sloupcu
[~,delsiKvalitniUsek]=max(diff(qualityMax'));
nejdelsiKvalitniUsek=qualityMax(delsiKvalitniUsek,:);

[QRSgPuvodni, inVar,  ~, inVarAM, ~, ~, inVar3AM] = det_LML_qrsVAR(fs,ecg');
QRSgPuvodni = round(QRSgPuvodni);
L1=[inVar,inVarAM,inVar3AM];
[QRSgKorr,~]=korekceR(QRSgPuvodni,ecg);
SNRf=median(SNRf);
vystupyZTetoCasti=[];


%% Andrea RWE
vlnka='db6';    % vlnka - db6 doporuena lnkem
pasem=3;        % zle na Fs (posledn psmo by mlo bt od 0 Hz do cca 15 Hz)
RR_int=QRSgPuvodni(2:end)-QRSgPuvodni(1:end-1);     % dlky RR interval
dseg=median(RR_int)/4;              % dlka segmentu TQ (lze pout adaptivn - za poslednch 10 cykl)
for i=1:length(QRSgPuvodni)
    od=round(QRSgPuvodni(i)-50/1000*fs-dseg); %zde misto odecteni 50 ms dat kubovi zacatky QRS!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    do=round(QRSgPuvodni(i)-50/1000*fs);
    if od<1 || do>length(ecg)
        continue
    end
    ecg2=ecg-mean(ecg); 
    TQ=ecg2(od:do);         % stanoven segmentu TQ, konec je 50 ms ped R
    L_TQ=length(TQ);                                                        % dlka segmentu
    % doplnn signlu nulami - kvli SWT
    if L_TQ==2^6 || L_TQ==2^7 || L_TQ==2^8
        TQ2=TQ;
%         continue
    elseif L_TQ>2^6 && L_TQ<2^7
        TQ2=zeros(1,2^7);
        TQ2(1:L_TQ)=TQ;
    elseif L_TQ>2^7 && L_TQ<2^8
        TQ2=zeros(1,2^8);
        TQ2(1:L_TQ)=TQ;
    elseif L_TQ<2^6% && L_TQ<2^7
        TQ2=zeros(1,2^6);
        TQ2(1:L_TQ)=TQ;
    else
        warndlg('Segment je man ne ne 2^6 nebo vt ne 2^7. Je poteba vytvoit dal podmnku.')
    end
        
    swc=swt(TQ2, pasem, vlnka);         % samotn SWT
    swc=swc(:,1:L_TQ);                  % zkrcen SWT koeficient na pvodn dlku segmentu
    
%     figure(12)
%     plot(signal,'k')
%     hold on
%     plot([zeros(1,round(Rka(i)-50/1000*Fs-dseg-1)),TQ],'r')
%     hold off

%     figure(13)
%     subplot(pasem+2,1,1)
%     plot(TQ)
    for j=1:pasem+1
%         subplot(pasem+2,1,j+1)
%         plot(swc(j,:))
        
        % vpoet relativn vlnkov energie v jednotlivch psmech WT (j) a
        % cyklech EKG (i)
        RWE(i,j)=sum(swc(j,:).^2)/sum(sum(swc.^2)); % v dcch jsou jednotliv cykly a ve sloupcch jsou psma WT od nejvych po nejni frekvence
    end  
end


%%
for re=1:4
    if re==1
        QRSg=QRSgPuvodni;
    elseif re==2
        
        if length(QRSgKorr)>=5
            QRSg=QRSgKorr(3:end-2);
        else
           QRSg=QRSgKorr;
           disp('malo QRS!!!!!')
        end
    elseif re==3
        QRSg=QRSgKorr;
    elseif re==4
        QRSg=QRSgKorr(QRSgKorr>nejdelsiKvalitniUsek(1) & QRSgKorr<nejdelsiKvalitniUsek(2));
    end
        
    RR = diff(QRSg)/fs;
    BPM=60./(RR);
    BPMstd=std(BPM);
    BPM=median(BPM);
    
    RR=RR';
    diffRR=diff(RR);
    diffRR=diffRR*1000;
    diffRR=abs(diffRR);
    RR50=sum(diffRR>50);
    pRR50=100*RR50/(length(RR)-1);%100x ptz prevadim na procenta
    
    RR100=sum(diffRR>100);
    pRR100=100*RR100/(length(RR)-1);%100x ptz prevadim na procenta
    
    RR150=sum(diffRR>150);
    pRR150=100*RR150/(length(RR)-1);%100x ptz prevadim na procenta
        
    RMSSD=sqrt(mean(diffRR.^2));
    
    SDSD=std(diffRR);
    
    RR20=sum(diffRR>20);
    pRR20=100*RR20/(length(RR)-1);%100x ptz prevadim na procenta
    
    skupinyRR=sort(RR*1000);%prevedu na ms a seradim
    while min(diff(skupinyRR))<50
        [~,poziceMinima]=min(diff(skupinyRR));
        novaSkupina=(skupinyRR(poziceMinima)+skupinyRR(poziceMinima+1))/2;
        skupinyRR(poziceMinima)=novaSkupina;
        skupinyRR(poziceMinima+1)=[];
        sort(skupinyRR);
    end
    pocetSkupinRR50=length(skupinyRR);
    
    skupinyRR=sort(RR*1000);%prevedu na ms a seradim
    while min(diff(skupinyRR))<100
        [~,poziceMinima]=min(diff(skupinyRR));
        novaSkupina=(skupinyRR(poziceMinima)+skupinyRR(poziceMinima+1))/2;
        skupinyRR(poziceMinima)=novaSkupina;
        skupinyRR(poziceMinima+1)=[];
        sort(skupinyRR);
    end
    pocetSkupinRR100=length(skupinyRR);
    
    vystupyZTetoCasti=[vystupyZTetoCasti;pRR50,pocetSkupinRR50,pocetSkupinRR100,pRR100,pRR150,RMSSD,SDSD,pRR20,BPM,BPMstd];
end
    
%% morfologicke trideni
IIR_high = designfilt('highpassiir', ...
        'FilterOrder',2, ...            
        'PassbandFrequency', 5, ...
        'PassbandRipple',0.05, ...
        'SampleRate', fs );

IIR_low = designfilt('lowpassiir', ...
        'FilterOrder',2, ...            
        'PassbandFrequency',30, ...
        'PassbandRipple',0.05, ...
        'SampleRate', fs );

ecgf = filtfilt( IIR_low, ecg );
ecgf = filtfilt( IIR_high, ecg);%zde je chyba - nutne nahradit ecg za ecgf!!!
mistniVystupy2=[];
for re=1:2
    mistniVystupy=[];
    if re==1
        QRSg=QRSgKorr;
    elseif re==2
        if length(QRSgKorr)>=5
            QRSg=QRSgKorr(3:end-2);
        else
           QRSg=QRSgKorr;
           disp('malo QRS!!!!!')
        end
    end
    for polomerQRS=[5,10]
            komplexyQRS=[];
        for k=1:length(QRSg)
            if QRSg(k)-3*polomerQRS>0 & QRSg(k)+3*polomerQRS<=length(ecgf)
                novyKomplex=ecgf(QRSg(k)-3*polomerQRS:QRSg(k)+3*polomerQRS)-mean(ecgf(QRSg(k)-3*polomerQRS:QRSg(k)+3*polomerQRS))-median(ecgf(QRSg(k)-3*polomerQRS:QRSg(k)+3*polomerQRS)-mean(ecgf(QRSg(k)-3*polomerQRS:QRSg(k)+3*polomerQRS)));   %vcetne odecteni stredni(medianove) hodnoty
                komplexyQRS=[komplexyQRS,novyKomplex]; %2krat protoze potrebuju si poslat vzorky do zalohy, kdybych to potreboval posouvat

            end
        end
        normalizace=1;
        [pocetTypu95,~,procentualniCetnostNejpocetnejsiSkupiny95,~,~,~,~]=shodaTvaru(komplexyQRS,0.95,normalizace);
        [pocetTypu98,pocetTypuOJednomQRS98,procentualniCetnostNejpocetnejsiSkupiny98,~,cetnostTypu,~,slucovaniCell90]=shodaTvaru(komplexyQRS,0.98,normalizace);
        mistniVystupy=[mistniVystupy,pocetTypu95,procentualniCetnostNejpocetnejsiSkupiny95,pocetTypu98,pocetTypuOJednomQRS98,procentualniCetnostNejpocetnejsiSkupiny98];
    end
    mistniVystupy2=[mistniVystupy2;mistniVystupy];
end
%%     
[pocetTypu98,pocetTypuOJednomQRS98,procentualniCetnostNejpocetnejsiSkupiny98,~,cetnostTypu,~,slucovaniCell90]=shodaTvaru(komplexyQRS,0.98,0);
%pNN:
[~,b]=max(cetnostTypu);
RRint=diff(QRSg(sort(slucovaniCell90{b})))/fs;
RRint=RRint(diff(sort(slucovaniCell90{b}))==1);
diffRR=diff(RRint);
diffRR=diffRR*1000;
diffRR=abs(diffRR);
RR50NN=sum(diffRR>50);
pRR50NN=100*RR50NN/(length(RRint)-1);%100x ptz prevadim na procenta

[Sig]=swt_features_fisi_huskova(ecg,fs);
H1=reshape(Sig{1,1},[1,24]);
K1Az4=Main(ecg,QRSgPuvodni);
%% klasifikace
    if RWE(1,1)==0
        RWE(1,:)=[];
    end
    p1=mean(RWE(:,1));
    p2=mean(RWE(:,2));
    p3=mean(RWE(:,3));
    p4=mean(RWE(:,4));
    m1=median(RWE(:,1));
    m2=median(RWE(:,2));
    m3=median(RWE(:,3));
    m4=median(RWE(:,4));
    A1az8=[p1,p2,p3,p4,m1,m2,m3,m4];

inputNonStand=[vystupyZTetoCasti(1,1),vystupyZTetoCasti(1,5),vystupyZTetoCasti(1,8),vystupyZTetoCasti(1,9),vystupyZTetoCasti(2,1),vystupyZTetoCasti(2,2),vystupyZTetoCasti(2,3),vystupyZTetoCasti(2,5:7),vystupyZTetoCasti(2,9:10),vystupyZTetoCasti(4,5),vystupyZTetoCasti(3,4:5),pRR50NN,SNRf,mistniVystupy2(1,[7,10]),mistniVystupy2(2,[1,7:10]),H1([11,18]),L1,K1Az4,A1az8];
inputNonStand(:,[16,21,37,39])=[];
    QRSgPuvodni2=QRSgPuvodni(2:end-1);
    [indIzoelVSignale]=detekceIzoelLinie(ecg,QRSgPuvodni2-12,fs,0);
    [indIzoelVSignale2]=detekceIzoelLinie(ecg,QRSgPuvodni2+40,fs,0);
    elevaceDeprese=(indIzoelVSignale-indIzoelVSignale2); 
    
    %% detekce pily
prehodDoOther=0;
RR = diff(QRSgPuvodni)/fs;
BPMZaloha=60./(RR);
if length(BPMZaloha)>15
    for ko=1:9:length(BPMZaloha)-15
        [lokmax,polohamax]=findpeaks(BPMZaloha(ko:ko+15));
        [lokmin,polohamin]=findpeaks(-BPMZaloha(ko:ko+15));
        lokmin=-lokmin;

        stdlokmax=std(lokmax);%hodnoty by mely byt zhruba stejny  - std mensi nez 5
        stdlokmin=std(lokmin);

        stdpolohamax=std(diff(polohamax));%vzdalenosti maxim od sebe a minim od sebe by mely byt zhruba stejny  - std mensi nez 1
        stdpolohamin=std(diff(polohamin));

        [~,serazeni]=sort([polohamax,polohamin]);
        extremy=[lokmax,lokmin];
        extremy=extremy(serazeni);
        stddifflokmax=std(abs(diff(extremy)));%velikost pily by mela byt porad vicemene stejna  - std mensi nez 5
        stddifflokmin=std(abs(diff(extremy)));


        mediandifflok=median(abs(diff(extremy)));%medianova velikost pily by mela byt alespon 10

        medianpolohamax=median(diff(polohamax));%vzdalenosti maxim/minim musi byt maximalne 10 vzorku
        medianpolohamin=median(diff(polohamin));
            if stdlokmax<5 && stdlokmin<5 && stdpolohamax<1 && stdpolohamin<1 && stddifflokmax<5 && stddifflokmin<5 && mediandifflok>10 && medianpolohamax<10 &&  medianpolohamin<10
            prehodDoOther=1;
            break
        end
    end
else
            [lokmax,polohamax]=findpeaks(BPMZaloha);
        [lokmin,polohamin]=findpeaks(-BPMZaloha);
        lokmin=-lokmin;

        stdlokmax=std(lokmax);%hodnoty by mely byt zhruba stejny  - std mensi nez 5
        stdlokmin=std(lokmin);

        stdpolohamax=std(diff(polohamax));%vzdalenosti maxim od sebe a minim od sebe by mely byt zhruba stejny  - std mensi nez 1
        stdpolohamin=std(diff(polohamin));

        [~,serazeni]=sort([polohamax,polohamin]);
        extremy=[lokmax,lokmin];
        extremy=extremy(serazeni);
        stddifflokmax=std(abs(diff(extremy)));%velikost pily by mela byt porad vicemene stejna  - std mensi nez 5
        stddifflokmin=std(abs(diff(extremy)));


        mediandifflok=median(abs(diff(extremy)));%medianova velikost pily by mela byt alespon 10

        medianpolohamax=median(diff(polohamax));%vzdalenosti maxim/minim musi byt maximalne 10 vzorku
        medianpolohamin=median(diff(polohamin));

        if stdlokmax<5 && stdlokmin<5 && stdpolohamax<1 && stdpolohamin<1 && stddifflokmax<5 && stddifflokmin<5 && mediandifflok>10 && medianpolohamax<10 &&  medianpolohamin<10
            prehodDoOther=1;
        end


%         if detekcePilyC(cisloSignalu,1)<5 && detekcePilyC(cisloSignalu,2)<5 && detekcePilyC(cisloSignalu,3)<1 && detekcePilyC(cisloSignalu,4)<1 && detekcePilyC(cisloSignalu,5)<5 && detekcePilyC(cisloSignalu,6)<5 && detekcePilyC(cisloSignalu,7)>10 && detekcePilyC(cisloSignalu,8)<10 &&  detekcePilyC(cisloSignalu,9)<10
%             prehodDoOther=1;
%         end
end
    detekcePily=[stdlokmax,stdlokmin,stdpolohamax,stdpolohamin,stddifflokmax,stddifflokmin,mediandifflok,medianpolohamax,medianpolohamin];

    inputNonStand=[inputNonStand,detekcePily,mean(elevaceDeprese)];
    inputNonStand=[inputNonStand,Feature,FeaturesPQRSPCA,FeaturePQRS1];%(:,kopi)];
%     inputNonStand(:,[19,47,61,25])=[];
elita=[1 1 1 0 1 1 0 0 1 0 1 1 1 0 0 0 0 1 1 1 0 1 1 1 0 0 1 1 0 1 0 0 1 1 1 0 1 0 1 1 0 1 1 1 1 0 1 1 0 1 0 1 1 1 1 1 1 1 0 1 1 0 1 1 1 0 1 0 0 1 1 1 1 1 0 0 1 1 1 1 0 1 0 0 1 1 1 1 0 1 0 1 1 1 0 1 1 1 1 1 1 1 1 0 0 1 1 1 0 0 0 1 0 0 1 0 1 0 0 1 0 0 1 0 1 1 0 1 1 1 0 0 0 1 0 1 1 1 1 1 1 0 0 1 1 1 0 0 0 1 0 0 1 1 0 1 0 0 1 0 1 0 0 1 1 0 1 1 1 1 1 0 0 1 0 1 1 1 0 0 1 1 0 1 1 1 0 0 0 0 0 0 1 0 1 1 0 0 1 0 0 1 0 0 1 0 0 0 0 1 1 0 1 1 0 0 0 1 0 0 0 1 0 1 0 1 1 1 0 0 0 0 1 1 1 1 1 1 0 0 1 1 0 0 1 1 0 1 1 0 0 1 1 1 1 1 0 1 0 0 0 1 1 1 1 1 1 1 0 0 1 0 0 0 0 1 1 0 1 0 0 1 0 0 1 0 0 1 0 1 0 1 1 1 0 1 0 0 0 1 0 0 1 1 0 0 0 0 1 1 0 1 1 1 0 1 1 1 1 1 0 0 0 1 1 0 1 1 1 1 0 0 1 1 1 0 0 0 1 0 1 0 0 0 1 0 0 1 1 1 0 0 0 1 0 0 1 0 1 0 0 0 1 1 0 1 1 0 1 0 1 0 0 1 1 0 1 0 0 1 0 1 0 0 0 0 1 0 1 1 0 1 1 0 1 0 0 0 1 1 0 1 1 1 0 1 1 1 0 0 1 1 1 1 1 0 0 1 0 0 0 0 0 0 0 0 0 1 1 1 0 1 0 1 0 1 0 1 1 1 1 1 0 0 1 1 1 1 0 1 0 0 0 0 1 1 0 1 1 0 0 1 0 1 0 0 1 1 1 0 0 1 1 1 1 0 0 0 1 1 0 0 1 1 1 0 0 0 0 0 1 1 1];
inputNonStand(~elita)=[];
% For standardized features:
inputStand=(inputNonStand-mitr)./(matr-mitr);
% inputNonStand - feature vector [1x25] calculated from one test signal


Class = predict(SV,inputStand);
stdlokmax=0; stdlokmin=0; stdpolohamax=0; stdpolohamin=0;stddifflokmax=0; stddifflokmin=0; mediandifflok=0; medianpolohamax=0; medianpolohamin=0;
switch Class
    case 0
        classifyResult = 'N';
    case 1
        classifyResult = 'A';
    case 2
        classifyResult = 'O';
    case 3
        classifyResult = '~';
end

% if (K1Az4(3)+K1Az4(4))>5 & (classifyResult == 'N' | classifyResult == 'O')
% 
%     classifyResult='O';
% end


if classifyResult == 'N' && (vystupyZTetoCasti(1,9)>100 || vystupyZTetoCasti(1,9)<50)
    classifyResult='O';
end

% if classifyResult == 'N'
%     QRSgPuvodni2=QRSgPuvodni(2:end-1);
%     [indIzoelVSignale]=detekceIzoelLinie(ecg,QRSgPuvodni2-12,fs,0);
%     [indIzoelVSignale2]=detekceIzoelLinie(ecg,QRSgPuvodni2+40,fs,0);
%     elevaceDeprese=(indIzoelVSignale-indIzoelVSignale2); 
%     if mean(elevaceDeprese)<-59.5
%         classifyResult='O';
%     end
% end
% % classifyResult2=classifyResult;
% if classifyResult == 'A'
%     prehodDoOther=0;
% 
% RR = diff(QRSgPuvodni)/fs;
% BPMZaloha=60./(RR);
% if length(BPMZaloha)>15
%     for ko=1:9:length(BPMZaloha)-15
%         [lokmax,polohamax]=findpeaks(BPMZaloha(ko:ko+15));
%         [lokmin,polohamin]=findpeaks(-BPMZaloha(ko:ko+15));
%         lokmin=-lokmin;
% 
%         stdlokmax=std(lokmax);%hodnoty by mely byt zhruba stejny  - std mensi nez 5
%         stdlokmin=std(lokmin);
% 
%         stdpolohamax=std(diff(polohamax));%vzdalenosti maxim od sebe a minim od sebe by mely byt zhruba stejny  - std mensi nez 1
%         stdpolohamin=std(diff(polohamin));
% 
%         [~,serazeni]=sort([polohamax,polohamin]);
%         extremy=[lokmax,lokmin];
%         extremy=extremy(serazeni);
%         stddifflokmax=std(abs(diff(extremy)));%velikost pily by mela byt porad vicemene stejna  - std mensi nez 5
%         stddifflokmin=std(abs(diff(extremy)));
% 
% 
%         mediandifflok=median(abs(diff(extremy)));%medianova velikost pily by mela byt alespon 10
% 
%         medianpolohamax=median(diff(polohamax));%vzdalenosti maxim/minim musi byt maximalne 10 vzorku
%         medianpolohamin=median(diff(polohamin));
% 
%         if stdlokmax<5 && stdlokmin<5 && stdpolohamax<1 && stdpolohamin<1 && stddifflokmax<5 && stddifflokmin<5 && mediandifflok>10 && medianpolohamax<10 &&  medianpolohamin<10
%             prehodDoOther=1;
%             break
%         end
%     end
% else
%             [lokmax,polohamax]=findpeaks(BPMZaloha);
%         [lokmin,polohamin]=findpeaks(-BPMZaloha);
%         lokmin=-lokmin;
% 
%         stdlokmax=std(lokmax);%hodnoty by mely byt zhruba stejny  - std mensi nez 5
%         stdlokmin=std(lokmin);
% 
%         stdpolohamax=std(diff(polohamax));%vzdalenosti maxim od sebe a minim od sebe by mely byt zhruba stejny  - std mensi nez 1
%         stdpolohamin=std(diff(polohamin));
% 
%         [~,serazeni]=sort([polohamax,polohamin]);
%         extremy=[lokmax,lokmin];
%         extremy=extremy(serazeni);
%         stddifflokmax=std(abs(diff(extremy)));%velikost pily by mela byt porad vicemene stejna  - std mensi nez 5
%         stddifflokmin=std(abs(diff(extremy)));
% 
% 
%         mediandifflok=median(abs(diff(extremy)));%medianova velikost pily by mela byt alespon 10
% 
%         medianpolohamax=median(diff(polohamax));%vzdalenosti maxim/minim musi byt maximalne 10 vzorku
%         medianpolohamin=median(diff(polohamin));
% 
%         if stdlokmax<5 && stdlokmin<5 && stdpolohamax<1 && stdpolohamin<1 && stddifflokmax<5 && stddifflokmin<5 && mediandifflok>10 && medianpolohamax<10 &&  medianpolohamin<10
%             prehodDoOther=1;
%         end
% 
% 
% %         if detekcePilyC(cisloSignalu,1)<5 && detekcePilyC(cisloSignalu,2)<5 && detekcePilyC(cisloSignalu,3)<1 && detekcePilyC(cisloSignalu,4)<1 && detekcePilyC(cisloSignalu,5)<5 && detekcePilyC(cisloSignalu,6)<5 && detekcePilyC(cisloSignalu,7)>10 && detekcePilyC(cisloSignalu,8)<10 &&  detekcePilyC(cisloSignalu,9)<10
% %             prehodDoOther=1;
% %         end
% end
% 
% 
% 
% % detekcePily=[stdlokmax,stdlokmin,stdpolohamax,stdpolohamin,stddifflokmax,stddifflokmin,mediandifflok,medianpolohamax,medianpolohamin];
% if prehodDoOther==1 && inputNonStand(1)>=87.5 && inputNonStand(2)>=37.5 && inputNonStand(8)>=37.5 && inputNonStand(13)>=25 && inputNonStand(15)>=25 
% %     reffile = ['training2017' filesep 'REFERENCE-v2.csv'];%validation  training2017 'REFERENCE-v2.csv' 'REFERENCE.csv'
% %     fid = fopen(reffile, 'r');
% %     if(fid ~= -1)
% %         Ref = textscan(fid,'%s %s','Delimiter',',');
% %     else
% %         error(['Could not open ' reffile ' for scoring. Exiting...'])
% %     end
% %     fclose(fid);
% %     target  = Ref{2};
% %    if strcmp(target{cisloSignalu},'A')
% %        pom=2;
% %    elseif strcmp(target{cisloSignalu},'N')
% %        pom=1;
% %    elseif strcmp(target{cisloSignalu},'O')
% %        pom=0;
% %    end
%     classifyResult='O';
% end  
end
% dalsiPriznaky=[stdlokmax, stdlokmin, stdpolohamax, stdpolohamin,stddifflokmax, stddifflokmin, mediandifflok, medianpolohamax, medianpolohamin];
