function quality = segment7(SNRf,fs,win,x)
% 8.3.2017 Martin Vitek
%
% quality = matrix with 3 columns
            % 1st = segments beginings
            % 2nd = segments endings
            % 3rd = segments quality
                    % quality 1 higher than thr2
                    % quality 2 between thr1 and thr2
                    % quality 3 lower than thr1
                 
%% parameters setting
thr1 = 0;       % lower threshold in dB
thr2 = 15;      % higher threshold in dB
sec1 = 15;       % minimum length of improved segment in seconds
sec2 = 3;       % minimum length of worsened segment in seconds
mean1 = 1;     % minimum mean of improved segment value in dB
mean2 = 1;     % minimum mean of worsened segment value in dB

%% segmentation algorithm
% quality vector Q - 1 best, 2 middle, 3 worst

tim1 = round(sec1*fs/win);  % time window for improved segment in samples
tim2 = round(sec2*fs/win);  % time window for worsened segment in samples

buff = [0 0;1 1];           % buffer for two latest thresholds crossings
                    
if SNRf(1)>= thr2           % first value
    Q = 1;
elseif SNRf(1)>= thr1 && SNRf(1)< thr2
    Q = 2;
else
    Q = 3;
end

% thresholding of other values
for i = 2:length(SNRf)
    % selecting quality level
    if SNRf(i)>= thr2
        Q(i) = 1;
    elseif SNRf(i)>= thr1 && SNRf(i)< thr2
        Q(i) = 2;
    else
        Q(i) = 3;
    end
    change = Q(i-1)-Q(i);
    if change ~= 0;
       % changing quality level
       backup = buff;
       buff = [buff(1,2) change; buff(2,2) i];
       
       % improved segment checking
       if (buff(2,2)-buff(2,1)< tim1 && buff(1,1)> 0) || ...
          (mean(abs(SNRf(buff(2,1):buff(2,2))-SNRf(buff(2,1))))< mean1 && buff(1,1)> 0)
             
          Q(buff(2,1):buff(2,2)-1)=Q(buff(2,1)-1);  % segment elimination
          buff = [backup(1,1) change; backup(2,1) i];

       % worsened segment checking
       elseif (buff(2,2)-buff(2,1)< tim2 && buff(1,1) < 0) || ...
          (mean(abs(SNRf(buff(2,1):buff(2,2))-SNRf(buff(2,1))))< mean2 && buff(1,1)< 0)
          
          Q(buff(2,1):buff(2,2)-1)=Q(buff(2,1)-1); % segment elimination
          buff = [backup(1,1) change; backup(2,1) i];
          
       end
    end    
end

temp = win*find(diff(Q));
borders = [0 temp length(x)];

for i = 1:length(borders)-1
    pom = Q((round((mean([borders(i)+1 borders(i+1)]))/win)));
    quality(i,:) = [borders(i)+1 borders(i+1) pom];
end
%% ploting result

% figure;
% subplot(211);
% plot(x);
% title('ECG signal')
% xlabel('samples [-]')
% ylabel('voltage [\muV]')
% hold on;
% y = axis;
% for i = 1:length(temp)
%     line([temp(i) temp(i)],[y(3) y(4)],'color','k','linewidth',2);
% end
% legend('Artificial ECG','Segments Borders','Location','northWest')
% 
% subplot(212);
% hold on;
% SNRx = 1:win:win*length(SNRf);
% plot(SNRx,SNRf,'r','linewidth',2);
% title('ECG segmentation')
% xlabel('samples [-]')
% ylabel('SNR [dB]')
% 
% % recalculating quality levels
% Q_plot = Q;
% place = find(Q==1);
% Q_plot(place) = 22.5;
% place = find(Q==2);
% Q_plot(place) = 7.5;
% place = find(Q==3);
% Q_plot(place) = -7.5;
% 
% % curve of final segments
% plot(SNRx,Q_plot,'k','linewidth',2)            
% legend('Estimated SNR','Segmentation','Location','northWest')
% line([1 length(x)],[thr1 thr1],'linewidth',2); hold on;   % lower threshold
% line([1 length(x)],[thr2 thr2],'linewidth',2); hold on;   % higher threshold


end